@@ -11,6 +11,8 @@
 #include "settings.h"
 
 #include <QDebug>
+#include <QDir>
+#include <QFileInfo>
 #include <QRegularExpression>
 
 #include <KLocalizedString>
@@ -117,7 +119,16 @@ void SageSession::login()
 
     m_process = new QProcess(this);
     m_process->start(SageSettings::self()->path().toLocalFile(), arguments);
-    m_process->waitForStarted();
+
+    if (!m_process->waitForStarted())
+    {
+        changeStatus(Session::Disable);
+        emit error(i18n("Failed to start Sage, please check Sage installation."));
+        emit loginDone();
+        delete m_process;
+        m_process = nullptr;
+        return;
+    }
 
     connect(m_process, &QProcess::readyRead, this, &SageSession::readStdOut);
     connect(m_process, &QProcess::readyReadStandardOutput, this, &SageSession::readStdOut);
@@ -158,10 +169,15 @@ void SageSession::login()
     //save the path to the worksheet as variable "__file__"
     //this variable is usually set by the "os" package when running a script
     //but when it is run in an interpreter (like sage server) it is not set
-    if (!m_worksheetPath.isEmpty())
+    const auto& path = worksheetPath();
+    if (!path.isEmpty())
     {
-        const QString cmd = QLatin1String("__file__ = '%1'");
-        evaluateExpression(cmd.arg(m_worksheetPath), Cantor::Expression::DeleteOnFinish, true);
+        auto cmd = QLatin1String("__file__ = '%1'").arg(path);
+        evaluateExpression(cmd, Cantor::Expression::DeleteOnFinish, true);
+
+        const auto& dir = QFileInfo(path).absoluteDir().absolutePath();
+        cmd = QLatin1String("cd '%1'").arg(dir);
+        evaluateExpression(cmd, Cantor::Expression::DeleteOnFinish, true);
     }
 
     //enable latex typesetting if needed
@@ -449,11 +465,6 @@ void SageSession::setTypesettingEnabled(bool enable)
     Cantor::Session::setTypesettingEnabled(enable);
 }
 
-void SageSession::setWorksheetPath(const QString& path)
-{
-    m_worksheetPath = path;
-}
-
 Cantor::CompletionObject* SageSession::completionFor(const QString& command, int index)
 {
     return new SageCompletionObject(command, index, this);
